pub fn create_bvh(
physics: &mut impl Physics,
desc: &PxBVHDesc,
) -> Option<Owner<Bvh>>Expand description
Cooks and creates a bounding volume hierarchy without going through a stream.
This method does the same as cook_bvh, but the produced BVH is not stored
into a stream but is directly inserted into the provided Physics.
A [crate::Bvh] object on success