pub struct PxExtendedVec3 { /* private fields */ }Trait Implementations
Sourceimpl Class<PxExtendedVec3> for PxExtendedVec3
impl Class<PxExtendedVec3> for PxExtendedVec3
Sourcefn as_ptr(&self) -> *const PxExtendedVec3
fn as_ptr(&self) -> *const PxExtendedVec3
Returns a raw const pointer to the wrapped type.
Retrieving a raw pointer is safe. However, pretty much any use of a raw pointer is unsafe.
In particular: this pointer should not be used to construct a second owning wrapper around the pointer.
Sourcefn as_mut_ptr(&mut self) -> *mut PxExtendedVec3
fn as_mut_ptr(&mut self) -> *mut PxExtendedVec3
Returns a raw mut pointer to the wrapped type.
Retrieving a raw pointer is safe. However, pretty much any use of a raw pointer is unsafe.
In particular: this pointer should not be used to construct a second owning wrapper around the pointer.
Sourceimpl Clone for PxExtendedVec3
impl Clone for PxExtendedVec3
Sourcefn clone(&self) -> PxExtendedVec3
fn clone(&self) -> PxExtendedVec3
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for PxExtendedVec3
Sourceimpl From<PxExtendedVec3> for PxExtendedVec3
impl From<PxExtendedVec3> for PxExtendedVec3
Sourcefn from(bounds: PxExtendedVec3) -> Self
fn from(bounds: PxExtendedVec3) -> Self
Converts to this type from the input type.
Sourceimpl From<PxExtendedVec3> for PxExtendedVec3
impl From<PxExtendedVec3> for PxExtendedVec3
Sourcefn from(value: PxExtendedVec3) -> Self
fn from(value: PxExtendedVec3) -> Self
Converts to this type from the input type.