pub struct ShapeFlags { /* private fields */ }Expand description
Flags for PxShapeFlag
Implementations
Sourceimpl PxShapeFlags
impl PxShapeFlags
pub const SimulationShape: PxShapeFlags
pub const SceneQueryShape: PxShapeFlags
pub const TriggerShape: PxShapeFlags
pub const Visualization: PxShapeFlags
Sourcepub const fn empty() -> PxShapeFlags
pub const fn empty() -> PxShapeFlags
Returns an empty set of flags.
Sourcepub const fn all() -> PxShapeFlags
pub const fn all() -> PxShapeFlags
Returns the set containing all flags.
Sourcepub const fn from_bits(bits: u8) -> Option<PxShapeFlags>
pub const fn from_bits(bits: u8) -> Option<PxShapeFlags>
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
Sourcepub const fn from_bits_truncate(bits: u8) -> PxShapeFlags
pub const fn from_bits_truncate(bits: u8) -> PxShapeFlags
Convert from underlying bit representation, dropping any bits that do not correspond to flags.
Sourcepub const unsafe fn from_bits_unchecked(bits: u8) -> PxShapeFlags
pub const unsafe fn from_bits_unchecked(bits: u8) -> PxShapeFlags
Convert from underlying bit representation, preserving all bits (even those not corresponding to a defined flag).
Safety
The caller of the bitflags! macro can chose to allow or
disallow extra bits for their bitflags type.
The caller of from_bits_unchecked() has to ensure that
all bits correspond to a defined flag or that extra bits
are valid for this bitflags type.
Sourcepub const fn intersects(&self, other: PxShapeFlags) -> bool
pub const fn intersects(&self, other: PxShapeFlags) -> bool
Returns true if there are flags common to both self and other.
Sourcepub const fn contains(&self, other: PxShapeFlags) -> bool
pub const fn contains(&self, other: PxShapeFlags) -> bool
Returns true if all of the flags in other are contained within self.
Sourcepub fn insert(&mut self, other: PxShapeFlags)
pub fn insert(&mut self, other: PxShapeFlags)
Inserts the specified flags in-place.
Sourcepub fn remove(&mut self, other: PxShapeFlags)
pub fn remove(&mut self, other: PxShapeFlags)
Removes the specified flags in-place.
Sourcepub fn toggle(&mut self, other: PxShapeFlags)
pub fn toggle(&mut self, other: PxShapeFlags)
Toggles the specified flags in-place.
Sourcepub fn set(&mut self, other: PxShapeFlags, value: bool)
pub fn set(&mut self, other: PxShapeFlags, value: bool)
Inserts or removes the specified flags depending on the passed value.
Sourcepub const fn intersection(self, other: PxShapeFlags) -> PxShapeFlags
pub const fn intersection(self, other: PxShapeFlags) -> PxShapeFlags
Returns the intersection between the flags in self and
other.
Specifically, the returned set contains only the flags which are
present in both self and other.
This is equivalent to using the & operator (e.g.
ops::BitAnd), as in flags & other.
Sourcepub const fn union(self, other: PxShapeFlags) -> PxShapeFlags
pub const fn union(self, other: PxShapeFlags) -> PxShapeFlags
Returns the union of between the flags in self and other.
Specifically, the returned set contains all flags which are
present in either self or other, including any which are
present in both (see Self::symmetric_difference if that
is undesirable).
This is equivalent to using the | operator (e.g.
ops::BitOr), as in flags | other.
Sourcepub const fn difference(self, other: PxShapeFlags) -> PxShapeFlags
pub const fn difference(self, other: PxShapeFlags) -> PxShapeFlags
Returns the difference between the flags in self and other.
Specifically, the returned set contains all flags present in
self, except for the ones present in other.
It is also conceptually equivalent to the “bit-clear” operation:
flags & !other (and this syntax is also supported).
This is equivalent to using the - operator (e.g.
ops::Sub), as in flags - other.
Sourcepub const fn symmetric_difference(self, other: PxShapeFlags) -> PxShapeFlags
pub const fn symmetric_difference(self, other: PxShapeFlags) -> PxShapeFlags
Returns the symmetric difference between the flags
in self and other.
Specifically, the returned set contains the flags present which
are present in self or other, but that are not present in
both. Equivalently, it contains the flags present in exactly
one of the sets self and other.
This is equivalent to using the ^ operator (e.g.
ops::BitXor), as in flags ^ other.
Sourcepub const fn complement(self) -> PxShapeFlags
pub const fn complement(self) -> PxShapeFlags
Returns the complement of this set of flags.
Specifically, the returned set contains all the flags which are
not set in self, but which are allowed for this type.
Alternatively, it can be thought of as the set difference
between Self::all() and self (e.g. Self::all() - self)
This is equivalent to using the ! operator (e.g.
ops::Not), as in !flags.