pub trait Base: Class<PxBase> + Sized {
// Provided methods
fn get_concrete_type_name(&self) -> Option<&str> { ... }
fn get_concrete_type(&self) -> ConcreteType { ... }
fn set_base_flag(&mut self, flag: BaseFlag, value: bool) { ... }
fn set_base_flags(&mut self, in_flags: BaseFlags) { ... }
fn get_base_flags(&self) -> BaseFlags { ... }
fn is_releasable(&self) -> bool { ... }
}Provided Methods
Sourcefn get_concrete_type_name(&self) -> Option<&str>
fn get_concrete_type_name(&self) -> Option<&str>
Get the name of the real type referenced by this pointer, or None if the returned string is not valid
Sourcefn get_concrete_type(&self) -> ConcreteType
fn get_concrete_type(&self) -> ConcreteType
Returns an enumerated value identifying the type.
This may return ConcreteType::Undefined in surprising situations,
notably this does not seem to work with get_active_actors. Use
get_type for actors if possible.
Sourcefn set_base_flag(&mut self, flag: BaseFlag, value: bool)
fn set_base_flag(&mut self, flag: BaseFlag, value: bool)
Set or unset the specified flag on this object.
Sourcefn set_base_flags(&mut self, in_flags: BaseFlags)
fn set_base_flags(&mut self, in_flags: BaseFlags)
Set the BaseFlags of this object. Note that replaces all flags currently
on the object. Use set_base_flag to set individual flags.
Sourcefn get_base_flags(&self) -> BaseFlags
fn get_base_flags(&self) -> BaseFlags
Read the BaseFlags of this object
Sourcefn is_releasable(&self) -> bool
fn is_releasable(&self) -> bool
Returns true if this object can be released, i.e., it is not subordinate.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".