pub struct Pvd { /* private fields */ }Expand description
A new type wrapper for PxPvd.
Implementations
Sourceimpl Pvd
impl Pvd
Sourcepub fn connect(
&mut self,
transport: &mut PvdTransport,
flags: InstrumentationFlags,
) -> bool
pub fn connect( &mut self, transport: &mut PvdTransport, flags: InstrumentationFlags, ) -> bool
Connect the visual debugger over the provided transport. Returns true
if the connection succeded.
Sourcepub fn disconnect(&mut self)
pub fn disconnect(&mut self)
Disconnect from the transport.
Sourcepub fn is_connected(&mut self, use_cached_status: bool) -> bool
pub fn is_connected(&mut self, use_cached_status: bool) -> bool
Check if the Pvd is connected. The cached status may be up to one frame out of date.
When use_cached_status is false, the low-level status is checked which requires locking
the network stream.
Sourcepub fn get_transport(&mut self) -> Option<&mut PvdTransport>
pub fn get_transport(&mut self) -> Option<&mut PvdTransport>
Get the transport connected to the Pvd, if there is one.